#line 1 "libxlu_disk_l.c"
#line 31 "libxlu_disk_l.l"
#define _GNU_SOURCE



#line 7 "libxlu_disk_l.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define xlu__disk_yy_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer xlu__disk_yy_create_buffer
#endif

#ifdef yy_delete_buffer
#define xlu__disk_yy_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer xlu__disk_yy_delete_buffer
#endif

#ifdef yy_scan_buffer
#define xlu__disk_yy_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer xlu__disk_yy_scan_buffer
#endif

#ifdef yy_scan_string
#define xlu__disk_yy_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string xlu__disk_yy_scan_string
#endif

#ifdef yy_scan_bytes
#define xlu__disk_yy_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes xlu__disk_yy_scan_bytes
#endif

#ifdef yy_init_buffer
#define xlu__disk_yy_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer xlu__disk_yy_init_buffer
#endif

#ifdef yy_flush_buffer
#define xlu__disk_yy_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer xlu__disk_yy_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define xlu__disk_yy_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state xlu__disk_yy_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define xlu__disk_yy_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer xlu__disk_yy_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define xlu__disk_yypush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state xlu__disk_yypush_buffer_state
#endif

#ifdef yypop_buffer_state
#define xlu__disk_yypop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state xlu__disk_yypop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define xlu__disk_yyensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack xlu__disk_yyensure_buffer_stack
#endif

#ifdef yylex
#define xlu__disk_yylex_ALREADY_DEFINED
#else
#define yylex xlu__disk_yylex
#endif

#ifdef yyrestart
#define xlu__disk_yyrestart_ALREADY_DEFINED
#else
#define yyrestart xlu__disk_yyrestart
#endif

#ifdef yylex_init
#define xlu__disk_yylex_init_ALREADY_DEFINED
#else
#define yylex_init xlu__disk_yylex_init
#endif

#ifdef yylex_init_extra
#define xlu__disk_yylex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra xlu__disk_yylex_init_extra
#endif

#ifdef yylex_destroy
#define xlu__disk_yylex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy xlu__disk_yylex_destroy
#endif

#ifdef yyget_debug
#define xlu__disk_yyget_debug_ALREADY_DEFINED
#else
#define yyget_debug xlu__disk_yyget_debug
#endif

#ifdef yyset_debug
#define xlu__disk_yyset_debug_ALREADY_DEFINED
#else
#define yyset_debug xlu__disk_yyset_debug
#endif

#ifdef yyget_extra
#define xlu__disk_yyget_extra_ALREADY_DEFINED
#else
#define yyget_extra xlu__disk_yyget_extra
#endif

#ifdef yyset_extra
#define xlu__disk_yyset_extra_ALREADY_DEFINED
#else
#define yyset_extra xlu__disk_yyset_extra
#endif

#ifdef yyget_in
#define xlu__disk_yyget_in_ALREADY_DEFINED
#else
#define yyget_in xlu__disk_yyget_in
#endif

#ifdef yyset_in
#define xlu__disk_yyset_in_ALREADY_DEFINED
#else
#define yyset_in xlu__disk_yyset_in
#endif

#ifdef yyget_out
#define xlu__disk_yyget_out_ALREADY_DEFINED
#else
#define yyget_out xlu__disk_yyget_out
#endif

#ifdef yyset_out
#define xlu__disk_yyset_out_ALREADY_DEFINED
#else
#define yyset_out xlu__disk_yyset_out
#endif

#ifdef yyget_leng
#define xlu__disk_yyget_leng_ALREADY_DEFINED
#else
#define yyget_leng xlu__disk_yyget_leng
#endif

#ifdef yyget_text
#define xlu__disk_yyget_text_ALREADY_DEFINED
#else
#define yyget_text xlu__disk_yyget_text
#endif

#ifdef yyget_lineno
#define xlu__disk_yyget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno xlu__disk_yyget_lineno
#endif

#ifdef yyset_lineno
#define xlu__disk_yyset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno xlu__disk_yyset_lineno
#endif

#ifdef yyget_column
#define xlu__disk_yyget_column_ALREADY_DEFINED
#else
#define yyget_column xlu__disk_yyget_column
#endif

#ifdef yyset_column
#define xlu__disk_yyset_column_ALREADY_DEFINED
#else
#define yyset_column xlu__disk_yyset_column
#endif

#ifdef yywrap
#define xlu__disk_yywrap_ALREADY_DEFINED
#else
#define yywrap xlu__disk_yywrap
#endif

#ifdef yyalloc
#define xlu__disk_yyalloc_ALREADY_DEFINED
#else
#define yyalloc xlu__disk_yyalloc
#endif

#ifdef yyrealloc
#define xlu__disk_yyrealloc_ALREADY_DEFINED
#else
#define yyrealloc xlu__disk_yyrealloc
#endif

#ifdef yyfree
#define xlu__disk_yyfree_ALREADY_DEFINED
#else
#define yyfree xlu__disk_yyfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define xlu__disk_yywrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyg->yytext_ptr -= yyg->yy_more_len; \
	yyleng = (int) (yy_cp - yyg->yytext_ptr); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 41
#define YY_END_OF_BUFFER 42
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[634] =
    {   0,
       40,   40,   42,   38,   39,   41, 8193,   38,   39,   41,
    16385, 8193,   38,   41,16385,   38,   39,   41,   39,   41,
       38,   39,   41,   38,   39,   41,   38,   39,   41,   38,
       39,   41,   38,   39,   41,   38,   39,   41,   38,   39,
       41,   38,   39,   41,   38,   39,   41,   38,   39,   41,
       38,   39,   41,   38,   39,   41,   38,   39,   41,   38,
       39,   41,   38,   39,   41,   38,   39,   41,   38,   39,
       41,   38,   39,   41,   40,   41,   41,   38,   38, 8193,
       38, 8193,   38,16385, 8193,   38, 8193,   38,   38, 8229,
       38,16421,   38,   38,   38,   38,   38,   38,   38,   38,

       38,   38,   38,   38,   38,   38,   38,   38,   38,   38,
       38,   38,   38,   38,   38,   38,   38,   38,   38,   40,
     8193,   38, 8193,   38, 8193, 8229,   38, 8229,   38, 8229,
       28,   38,   38,   38,   38,   38,   38,   38,   38,   38,
       38,   38,   38,   38,   38,   38,   38,   38,   38,   38,
       38,   38,   38,   38,   38,   38,   38,   38,   38, 8229,
       38, 8229,   38, 8229,   28,   38,   38,   33, 8229,   38,
    16421,   38,   38,   16,   38,   38,   38,   38,   38,   38,
       38,   38,   38,   38, 8222, 8229,   38,16414,16421,   38,
       38,   36, 8229,   38,16421,   38, 8221, 8229,   38,16413,

    16421,   38,   38,   38, 8224, 8229,   38,16416,16421,   38,
       38,   38,   38,   38,   38,   38,   33, 8229,   38,   33,
     8229,   38,   33,   38,   33, 8229,   38,    3,   38,   16,
       38,   38,   38,   38,   38,   35, 8229,   38,16421,   38,
       38,   38,   38, 8222, 8229,   38, 8222, 8229,   38, 8222,
       38, 8222, 8229,   38,   38,   36, 8229,   38,   36, 8229,
       38,   36,   38,   36, 8229, 8221, 8229,   38, 8221, 8229,
       38, 8221,   38, 8221, 8229,   38,   38, 8224, 8229,   38,
     8224, 8229,   38, 8224,   38, 8224, 8229,   38,   38,   38,
       38,   11,   38,   38,   33, 8229,   38,   33, 8229,   38,

       33, 8229,   33,   38,   33,   38,    3,   38,   38,   38,
       38,   38,   38,   38,   35, 8229,   38,   35, 8229,   38,
       35,   38,   35, 8229,   38,   38,   38,   34, 8229,   38,
    16421, 8222, 8229,   38, 8222, 8229,   38, 8222, 8229, 8222,
       38, 8222,   38,   38,   36, 8229,   38,   36, 8229,   38,
       36, 8229,   36,   38,   36, 8221, 8229,   38, 8221, 8229,
       38, 8221, 8229, 8221,   38, 8221,   38,   38, 8224, 8229,
       38, 8224, 8229,   38, 8224, 8229, 8224,   38, 8224,   38,
       38,   38,   38,   11,   28,   11,    7,   38,   38,   38,
       38,   38,   38,   38,   14,   38,   35, 8229,   38,   35,

     8229,   38,   35, 8229,   35,   38,   35,    2,   38,   38,
       34, 8229,   38,   34, 8229,   38,   34,   38,   34, 8229,
       17,   38,   38,   12,   38,   38,   27,   23,   38,   38,
       11,   11,   28,    7,   28,    7,   38,    8,   38,   38,
       38,   38,    6,   38,   14,   38,    2,   28,    2,   38,
       38,   34, 8229,   38,   34, 8229,   38,   34, 8229,   34,
       38,   34,   17,   38,   38,   12,   28,   12,   38,   31,
     8229,   38,16421,   27,   28,   27,   23,   38,   38,    7,
        7,   28,   38,    8,   28,    8,   38,   38,   38,   38,
        6,   28,    6,    6,   28,    6,   28,   38,    2,    2,

       28,   38,   38,   38,   12,   12,   28,   38,   31, 8229,
       38,   31, 8229,   38,   31,   38,   31, 8229,   27,   28,
       24,   38,   38,    8,    8,   28,   38,   38,   18,   19,
        6,    6,   28,    6,    6,   38,   38,   38,   15,   38,
       38,   31, 8229,   38,   31, 8229,   38,   31, 8229,   31,
       38,   31,   24,   38,   38,   38,   38,   18,   28,   18,
       19,   28,   19,    6,    6,   38,   38,   38,   15,   38,
       38,   21,    9,   20,   18,   18,   28,   19,   19,   28,
        6,    5,    6,   38,   22,   38,   21,   28,   21,    9,
       28,    9,   20,   28,   20,    4,    6,    5,    6,   38,

       26,   25,   22,   28,   22,   38,   21,   21,   28,    9,
        9,   28,   20,   20,   28,    4,    6,   13,   38,   26,
       25,   22,   22,   28,   10,   13,   38,   10,   28,   10,
       10,   10,   28
    } ;

static const flex_int16_t yy_accept[406] =
    {   0,
        1,    1,    1,    2,    3,    4,    7,   12,   16,   19,
       21,   24,   27,   30,   33,   36,   39,   42,   45,   48,
       51,   54,   57,   60,   63,   66,   69,   72,   75,   77,
       78,   79,   80,   82,   85,   87,   88,   89,   90,   93,
       93,   94,   95,   96,   97,   98,   99,  100,  101,  102,
      103,  104,  105,  106,  107,  108,  109,  110,  111,  112,
      113,  114,  115,  116,  117,  118,  119,  120,  121,  123,
      125,  126,  128,  130,  131,  132,  133,  134,  135,  136,
      137,  138,  139,  140,  141,  142,  143,  144,  145,  146,
      147,  148,  149,  150,  151,  152,  153,  154,  155,  156,

      157,  158,  159,  160,  162,  164,  165,  166,  167,  168,
      172,  173,  174,  176,  177,  178,  179,  180,  181,  182,
      183,  184,  185,  190,  191,  192,  196,  197,  202,  203,
      204,  205,  210,  211,  212,  213,  214,  215,  216,  217,
      220,  223,  225,  227,  228,  230,  232,  233,  234,  235,
      236,  240,  241,  242,  243,  244,  247,  250,  252,  254,
      255,  256,  259,  262,  264,  266,  269,  272,  274,  276,
      277,  278,  281,  284,  286,  288,  289,  290,  291,  292,
      293,  294,  295,  298,  301,  303,  305,  306,  307,  309,
      310,  311,  312,  313,  314,  315,  318,  321,  323,  325,

      326,  327,  328,  332,  335,  338,  340,  342,  343,  344,
      345,  348,  351,  353,  355,  356,  359,  362,  364,  366,
      367,  368,  369,  372,  375,  377,  379,  380,  381,  382,
      383,  384,  386,  387,  388,  389,  390,  391,  392,  393,
      394,  395,  397,  400,  403,  405,  407,  408,  409,  410,
      411,  414,  417,  419,  421,  423,  424,  425,  426,  427,
      428,  430,  431,  432,  434,  436,  437,  438,  439,  440,
      441,  442,  443,  444,  445,  447,  449,  450,  451,  452,
      455,  458,  460,  462,  463,  465,  466,  468,  469,  470,
      474,  476,  477,  479,  480,  481,  483,  484,  486,  487,

      488,  489,  490,  491,  493,  494,  496,  498,  499,  500,
      502,  503,  504,  505,  506,  508,  509,  512,  515,  517,
      519,  521,  523,  524,  525,  527,  528,  529,  530,  531,
      532,  534,  535,  536,  537,  538,  539,  541,  542,  545,
      548,  550,  552,  553,  555,  556,  557,  558,  560,  561,
      563,  564,  565,  566,  567,  568,  569,  571,  572,  573,
      574,  575,  576,  578,  579,  581,  582,  584,  585,  585,
      586,  587,  589,  590,  592,  593,  595,  596,  598,  600,
      601,  602,  603,  605,  606,  607,  608,  610,  611,  613,
      614,  616,  618,  620,  621,  622,  623,  625,  626,  628,

      630,  631,  632,  634,  634
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    4,    5,    1,    1,    6,    7,    8,
        9,    9,    9,    9,    9,    9,    9,   10,    1,    1,
       11,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,   12,    1,   13,   14,   15,   16,

       17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
       27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
       37,   22,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[38] =
    {   0,
        1,    1,    2,    3,    1,    1,    1,    1,    1,    1,
        4,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[476] =
    {   0,
        0,    0, 1008, 1007, 1009, 1004,   36,   39, 1012, 1012,
       50,   71,   32,   72,   31,   43,   33,   45,   64,  994,
       65,   67,   54,  993,   73,   77,   83,   84,    0, 1012,
     1001, 1012,   95,  108,    0,    0,  119,  991,  131,    0,
      112,   81,   90,  115,  100,  103,  125,  101,  104,  126,
      127,  990,  133,  134,  139,  145,  154,  135,  147,  140,
      149,  151,  150,  152,   36,  153,  160,    0,  178,    0,
        0,  180,    0,    0,  998,  173,  156,  182,  174,  175,
      180,  181,  183,  186,  190,  191,  185,  192,  196,  198,
      201,  206,  232,  207,  202,  211,  209,  212,  241,  226,

      215,  225,  216,  249,    0,    0, 1012,  227,  228,  262,
      258,  243,  265,  246,  264,  988,  271,  987,  248,  269,
      263,  272,  296,  275,  273,  308,  313,  326,  304,  274,
      312,  338,  303,  334,  301,  302,  292,  321,  340,  351,
        0,  355,    0,  343,  357, 1012,  348,  332,  354,  358,
      388,  362,  360,  361,  367,  392,    0,  398,    0,  389,
      366,  403,    0,  407,    0,  412,    0,  416,    0,  399,
      213,  418,    0,  421,    0,  395,  404,  366,  415,  995,
      333,  425,  430,    0,    0,    0,    0,  424, 1012,  427,
      429,  432,  422,  444,  437,  451,    0,  457,    0,  453,

      447,  460,  480,  466,    0,    0,    0,    0,  459,  369,
      468,    0,    0,    0,    0,  484,    0,    0,    0,    0,
      465,  476,  490,    0,    0,    0,    0,  483,  487,  486,
      490,  994, 1012,  993,  489,  496,  495,  498,  500,  506,
      505,  454,  521,    0,    0,    0,    0,  992,  504,  518,
      533,    0,  535,    0,  527,  532,  991,  536,  540,  537,
      514,  539,  990, 1012,  989, 1012,  539,  988,  544,  543,
      546,  548,  561,  552, 1012,  987, 1012,  562,  567,  581,
        0,    0,    0,    0, 1012,  556,  986, 1012,  976,  592,
      984,    0, 1012,  574,  983, 1012,  558,  982, 1012,  578,

      583,  594,  596,  981, 1012,  288,  596,  603,  930, 1012,
      597,  599,  605,  918, 1012,  609,  620,    0,  622,    0,
        0,  623,  619,  902, 1012,  615,  622,  890,  862,  850,
     1012,  625,  635,  628,  636,  633,  642,  639,  658,    0,
        0,    0,    0, 1012,  652,  634,  659,  838, 1012,  834,
     1012,  646,  660,  663,  661,  666, 1012,  658,  830,  826,
      818,  810, 1012,  802, 1012,  676,  794,  671,  684,  786,
      671,  778, 1012,  766, 1012,  738, 1012,  731, 1012,  677,
      722,  714,  691, 1012,  685,  647, 1012,  565, 1012,  508,
     1012, 1012,  684, 1012, 1012,  448, 1012,  374, 1012,  167,

     1012,  122, 1012, 1012,  701,  705,  708,  712,  716,  720,
      724,  728,  732,  736,  740,  744,  748,  752,  756,  760,
      764,  768,  772,  776,  780,  784,  788,  792,  796,  800,
      804,  808,  812,  816,  820,  824,  828,  832,  836,  840,
      844,  848,  852,  856,  860,  864,  868,  872,  876,  880,
      884,  888,  892,  896,  900,  904,  908,  912,  916,  920,
      924,  928,  932,  936,  940,  944,  948,  952,  956,  960,
      964,  968,  972,  976,  980
    } ;

static const flex_int16_t yy_def[476] =
    {   0,
      404,    1,  405,  405,  404,  406,  407,  407,  404,  404,
      408,  408,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,  409,  404,
      406,  404,  410,  407,  411,  411,  412,   12,  406,  413,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,  409,  410,  411,
      411,  414,  415,  415,  404,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,  412,   12,   12,   12,   12,   12,   12,   12,

       12,   12,   12,  414,  415,  415,  404,   12,   12,  416,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,  417,   93,   93,  418,   12,  419,   12,   12,
       12,  420,   12,   12,   12,   12,   12,   12,   12,  421,
      422,  416,  422,   12,   12,  404,   93,   12,   12,   12,
      423,   12,   12,   12,   12,  424,  425,  417,  425,   93,
       93,  426,  427,  418,  427,  428,  429,  419,  429,   12,
       12,  430,  431,  420,  431,   12,   12,   12,   12,  432,
       12,   12,  421,  422,  422,  433,  433,   12,  404,   93,
       93,   93,   12,   12,   12,  434,  435,  423,  435,   12,

      406,   12,  436,  424,  425,  425,  437,  437,   93,   93,
      426,  427,  427,  438,  438,  428,  429,  429,  439,  439,
       12,   12,  430,  431,  431,  440,  440,   12,   12,   12,
       12,  441,  404,  442,   93,   12,   93,   93,   93,   12,
       93,   12,  434,  435,  435,  443,  443,  444,  406,   93,
      445,  446,  436,  446,   93,   93,  447,   12,   12,  448,
       12,   12,  441,  404,  449,  404,   93,  450,   12,   93,
       93,   93,  451,   93,  404,  452,  404,  406,   93,  445,
      446,  446,  453,  453,  404,   93,  454,  404,   12,  455,
      456,  456,  404,   12,  449,  404,   93,  457,  404,   12,

       93,   93,   93,  458,  404,  458,  458,   93,  452,  404,
      406,   93,   93,  454,  404,   12,  459,  460,  455,  460,
      456,   12,   93,  457,  404,   12,   93,  461,  462,  458,
      404,  458,  458,   93,  406,   93,   93,   12,  459,  460,
      460,  463,  463,  404,   93,   12,   93,  464,  404,  465,
      404,  458,  458,   93,  406,   93,  404,   12,  466,  467,
      468,  464,  404,  465,  404,  458,  458,   93,  404,  469,
       12,  470,  404,  471,  404,  472,  404,  458,  404,   93,
      404,  404,  473,  404,   12,  470,  404,  471,  404,  472,
      404,  404,   93,  404,  404,  473,  404,  474,  404,  475,

      404,  475,  404,    0,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404
    } ;

static const flex_int16_t yy_nxt[1050] =
    {   0,
        6,    7,    8,    9,    6,    6,    6,    6,    6,    6,
       10,    6,   11,   12,   13,   14,   15,   16,   17,   18,
       19,   20,   20,   20,   20,   21,   20,   22,   23,   24,
       25,   26,   27,   28,   20,   20,   20,   34,   34,   35,
       34,   34,   35,   38,   38,   38,   36,   44,   38,   36,
       31,   31,   31,   32,   37,   38,   49,   38,   45,   39,
       40,   31,   52,   50,   41,   53,   38,  102,   59,   51,
       42,   31,   31,   31,   32,   37,   38,   38,   56,   38,
       39,   40,   31,   43,   38,   38,   58,   61,   46,   63,
       54,   57,   47,   38,   55,   38,   38,   31,   70,   66,

       62,   48,   38,   67,   79,   71,   64,   78,   65,   34,
       34,   35,   38,   38,   85,   38,   38,   56,   36,   31,
       31,   31,   32,   81,   38,  401,   76,   38,   31,   40,
       31,   72,   72,   72,   73,   72,   82,   38,   38,   38,
       72,   74,   72,   77,   80,   38,   38,   38,   89,   86,
       90,   38,   38,   91,   83,   84,   87,   38,   93,   38,
       92,   38,   38,   38,   38,   38,   38,   98,   38,  103,
      403,   94,   38,   95,   96,   96,  109,   99,   97,  100,
       31,   70,   31,  105,  101,   38,   38,   38,   71,  108,
      106,  110,   38,   38,   38,   38,  111,   38,   38,  115,

      116,  112,   38,   38,   38,   92,  113,  117,   38,  118,
       38,  120,  114,   38,   38,  123,  126,  119,   38,   38,
      128,   38,  121,   38,   38,   38,  130,   38,   38,  129,
      222,  122,   31,   31,   31,   32,  127,   38,   38,   38,
       38,   31,   40,   31,  134,  135,  124,  125,  131,  137,
      132,   31,  105,   38,  136,   38,  133,  138,   38,  106,
       38,  139,  140,  140,   72,  141,  140,  145,  146,  147,
       38,  140,  143,  140,  144,   38,   38,   38,  149,  153,
      151,   38,  148,   38,   38,  154,   38,   37,   37,   37,
       37,  331,   92,  161,  171,  155,  156,  156,   72,  157,

      156,  160,  180,  332,   38,  156,  159,  156,  162,  162,
       72,  163,  162,   38,   38,   38,   38,  162,  165,  162,
       96,  132,  128,  176,   38,   38,  166,  166,   72,  167,
      166,  170,  178,   38,  179,  166,  169,  166,  172,  172,
       72,  173,  172,  234,   38,   38,   38,  172,  175,  172,
      177,  181,   38,   31,  184,   38,  182,   31,  186,  193,
      189,  185,   37,   37,  190,  187,   38,  191,  188,   38,
       38,  201,   38,   38,   38,  192,  203,  401,   38,   38,
       37,   37,  230,  256,   37,  194,  202,  195,  196,  196,
       72,  197,  196,  200,   31,  205,  210,  196,  199,  196,

       31,  207,  206,   37,   37,   31,  212,   38,  208,   31,
      214,   38,  209,  213,   31,  217,   38,  215,   31,  219,
       31,  224,  218,   31,  226,  228,  220,   38,  225,  235,
      221,  227,   31,  184,   38,  229,   38,   38,  240,  236,
      185,   37,   37,   37,   37,  231,   37,   37,  241,   38,
       32,  384,  242,   31,  244,  238,   38,  275,  239,   31,
      246,  245,  237,  248,  250,   38,   38,  247,   31,  205,
       31,  212,   38,   37,   37,  257,  206,   38,  213,  249,
      251,  251,   72,  252,  251,  255,   31,  217,   38,  251,
      254,  251,   31,  224,  218,   38,  258,  260,   38,   38,

      225,  261,   38,   37,  267,  259,  268,   32,   38,   37,
       37,  377,   37,   37,   37,   37,  273,  293,   38,   37,
       37,  262,  270,   31,  244,  274,   38,  269,  271,  272,
      285,  245,   37,  279,  278,   31,  281,   31,  283,   75,
      292,   37,   37,  282,  286,  284,   37,   37,   38,  290,
      289,   38,   38,   37,   37,  294,   38,   37,   37,  297,
       37,   37,   37,   37,  305,   32,   37,   37,  375,  301,
       37,   37,   37,   37,  311,  306,  307,  302,  308,  303,
      300,   37,   37,   31,  281,  313,   38,  312,  323,  322,
       38,  282,  317,  317,   72,  318,  317,   37,   37,  331,

       32,  317,  320,  317,  328,  326,  329,  334,   37,   37,
       37,   37,  327,   37,   37,  335,  333,   37,   37,   37,
      337,   38,   31,  340,   31,  342,  344,   38,  305,  336,
      341,  346,  343,   37,   37,   38,   37,   37,  305,   32,
      338,  345,   37,   37,  360,  357,   38,   37,   37,  305,
      373,   38,  355,  347,  352,  356,   37,   37,  354,  358,
       31,  340,  359,  305,   32,  353,   37,   37,  341,  361,
       38,  369,  366,   37,   37,  368,  370,   37,   37,  305,
       37,   37,  367,   38,  371,   37,   37,  399,  380,  381,
      382,   37,   37,  393,  397,  398,  385,   38,   37,   37,

      378,   29,   29,   29,   29,   31,   31,   31,   33,   33,
       33,   33,   38,   38,   38,   38,   68,  395,   68,   68,
       69,   69,   69,   69,   71,  394,   71,   71,   37,   37,
       37,   37,   75,   75,  392,   75,  104,  104,  104,  104,
      106,  391,  106,  106,  142,  142,  142,  142,  158,  158,
      158,  158,  164,  164,  164,  164,  168,  168,  168,  168,
      174,  174,  174,  174,  183,  183,  183,  183,  185,  389,
      185,  185,  198,  198,  198,  198,  204,  204,  204,  204,
      206,  387,  206,  206,  211,  211,  211,  211,  213,  384,
      213,  213,  216,  216,  216,  216,  218,  379,  218,  218,

      223,  223,  223,  223,  225,  351,  225,  225,  232,  232,
      232,  232,  187,  349,  187,  187,  243,  243,  243,  243,
      245,  377,  245,  245,  253,  253,  253,  253,  208,  375,
      208,  208,  215,  373,  215,  215,  220,  365,  220,  220,
      227,  363,  227,  227,  263,  263,  263,  263,  265,  265,
      265,  265,  247,  305,  247,  247,  276,  276,  276,  276,
      280,  280,  280,  280,  282,  351,  282,  282,  287,  287,
      287,  287,  291,  291,  291,  291,  295,  295,  295,  295,
      298,  298,  298,  298,  304,  304,  304,  304,  309,  309,
      309,  309,  284,  349,  284,  284,  314,  314,  314,  314,

      319,  319,  319,  319,  292,  299,  292,  292,  324,  324,
      324,  324,  330,  330,  330,  330,  339,  339,  339,  339,
      341,  288,  341,  341,  348,  348,  348,  348,  350,  350,
      350,  350,  343,  277,  343,  343,  362,  362,  362,  362,
      364,  364,  364,  364,  372,  372,  372,  372,  374,  374,
      374,  374,  376,  376,  376,  376,  383,  383,  383,  383,
      386,  386,  386,  386,  388,  388,  388,  388,  390,  390,
      390,  390,  396,  396,  396,  396,  400,  400,  400,  400,
      402,  402,  402,  402,  331,  325,  266,  321,  316,  315,
      310,  299,  296,  233,  288,  277,  266,  264,  233,  152,

      150,  107,   88,   38,   32,   60,   38,   32,  404,   30,
       30,    5,  404,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  404,  404,  404
    } ;

static const flex_int16_t yy_chk[1050] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    7,    7,    7,
        8,    8,    8,   15,   13,   17,    7,   13,   65,    8,
       11,   11,   11,   11,   11,   16,   15,   18,   13,   11,
       11,   11,   17,   16,   11,   18,   23,   65,   23,   16,
       11,   12,   12,   12,   12,   12,   19,   21,   21,   22,
       12,   12,   12,   12,   14,   25,   22,   25,   14,   26,
       19,   21,   14,   42,   19,   27,   28,   33,   33,   28,

       25,   14,   43,   28,   43,   33,   26,   42,   27,   34,
       34,   34,   45,   48,   48,   46,   49,   49,   34,   37,
       37,   37,   37,   45,   41,  402,   41,   44,   37,   37,
       37,   39,   39,   39,   39,   39,   46,   47,   50,   51,
       39,   39,   39,   41,   44,   53,   54,   58,   53,   50,
       54,   55,   60,   55,   47,   47,   51,   56,   57,   59,
       56,   61,   63,   62,   64,   66,   57,   62,   77,   66,
      400,   58,   67,   59,   60,   67,   77,   63,   61,   63,
       69,   69,   72,   72,   64,   76,   79,   80,   69,   76,
       72,   78,   81,   82,   78,   83,   79,   87,   84,   83,

       84,   80,   85,   86,   88,   85,   81,   86,   89,   87,
       90,   89,   82,   91,   95,   92,   94,   88,   92,   94,
       96,   97,   90,   96,   98,  171,   98,  101,  103,   97,
      171,   91,   93,   93,   93,   93,   95,  102,  100,  108,
      109,   93,   93,   93,  100,  101,   93,   93,   99,  103,
       99,  104,  104,   99,  102,  112,   99,  108,  114,  104,
      119,  109,  110,  110,  110,  110,  110,  112,  113,  113,
      111,  110,  110,  110,  111,  121,  115,  113,  115,  119,
      117,  120,  114,  117,  122,  120,  130,  125,  125,  124,
      124,  306,  122,  125,  130,  121,  123,  123,  123,  123,

      123,  124,  137,  306,  137,  123,  123,  123,  126,  126,
      126,  126,  126,  135,  136,  133,  129,  126,  126,  126,
      127,  131,  127,  133,  131,  127,  128,  128,  128,  128,
      128,  129,  135,  138,  136,  128,  128,  128,  132,  132,
      132,  132,  132,  181,  148,  181,  134,  132,  132,  132,
      134,  138,  139,  140,  140,  144,  139,  142,  142,  148,
      145,  140,  147,  147,  147,  142,  149,  147,  144,  145,
      150,  153,  153,  154,  152,  147,  155,  398,  178,  155,
      161,  161,  178,  210,  210,  149,  154,  150,  151,  151,
      151,  151,  151,  152,  156,  156,  161,  151,  151,  151,

      158,  158,  156,  160,  160,  162,  162,  176,  158,  164,
      164,  170,  160,  162,  166,  166,  177,  164,  168,  168,
      172,  172,  166,  174,  174,  176,  168,  179,  172,  182,
      170,  174,  183,  183,  193,  177,  188,  182,  193,  188,
      183,  190,  190,  191,  191,  179,  192,  192,  194,  195,
      201,  396,  195,  196,  196,  191,  194,  242,  192,  198,
      198,  196,  190,  200,  202,  200,  242,  198,  204,  204,
      211,  211,  202,  209,  209,  221,  204,  221,  211,  201,
      203,  203,  203,  203,  203,  209,  216,  216,  222,  203,
      203,  203,  223,  223,  216,  228,  222,  229,  230,  229,

      223,  230,  231,  235,  235,  228,  236,  249,  236,  237,
      237,  390,  238,  238,  239,  239,  240,  261,  240,  241,
      241,  231,  237,  243,  243,  241,  261,  236,  238,  239,
      255,  243,  250,  250,  249,  251,  251,  253,  253,  260,
      260,  255,  255,  251,  256,  253,  256,  256,  258,  259,
      258,  262,  259,  267,  267,  262,  269,  270,  270,  267,
      271,  271,  272,  272,  273,  278,  274,  274,  388,  270,
      286,  286,  297,  297,  278,  273,  273,  271,  274,  272,
      269,  279,  279,  280,  280,  286,  294,  279,  297,  294,
      300,  280,  290,  290,  290,  290,  290,  301,  301,  307,

      311,  290,  290,  290,  302,  300,  303,  308,  302,  302,
      303,  303,  301,  312,  312,  311,  307,  308,  308,  313,
      313,  316,  317,  317,  319,  319,  322,  326,  332,  312,
      317,  326,  319,  323,  323,  322,  327,  327,  333,  335,
      316,  323,  334,  334,  346,  337,  346,  336,  336,  352,
      386,  338,  335,  327,  332,  336,  337,  337,  334,  338,
      339,  339,  345,  353,  355,  333,  345,  345,  339,  347,
      358,  355,  352,  347,  347,  354,  356,  354,  354,  366,
      356,  356,  353,  371,  358,  368,  368,  393,  368,  369,
      369,  380,  380,  380,  383,  385,  371,  385,  393,  393,

      366,  405,  405,  405,  405,  406,  406,  406,  407,  407,
      407,  407,  408,  408,  408,  408,  409,  382,  409,  409,
      410,  410,  410,  410,  411,  381,  411,  411,  412,  412,
      412,  412,  413,  413,  378,  413,  414,  414,  414,  414,
      415,  376,  415,  415,  416,  416,  416,  416,  417,  417,
      417,  417,  418,  418,  418,  418,  419,  419,  419,  419,
      420,  420,  420,  420,  421,  421,  421,  421,  422,  374,
      422,  422,  423,  423,  423,  423,  424,  424,  424,  424,
      425,  372,  425,  425,  426,  426,  426,  426,  427,  370,
      427,  427,  428,  428,  428,  428,  429,  367,  429,  429,

      430,  430,  430,  430,  431,  364,  431,  431,  432,  432,
      432,  432,  433,  362,  433,  433,  434,  434,  434,  434,
      435,  361,  435,  435,  436,  436,  436,  436,  437,  360,
      437,  437,  438,  359,  438,  438,  439,  350,  439,  439,
      440,  348,  440,  440,  441,  441,  441,  441,  442,  442,
      442,  442,  443,  330,  443,  443,  444,  444,  444,  444,
      445,  445,  445,  445,  446,  329,  446,  446,  447,  447,
      447,  447,  448,  448,  448,  448,  449,  449,  449,  449,
      450,  450,  450,  450,  451,  451,  451,  451,  452,  452,
      452,  452,  453,  328,  453,  453,  454,  454,  454,  454,

      455,  455,  455,  455,  456,  324,  456,  456,  457,  457,
      457,  457,  458,  458,  458,  458,  459,  459,  459,  459,
      460,  314,  460,  460,  461,  461,  461,  461,  462,  462,
      462,  462,  463,  309,  463,  463,  464,  464,  464,  464,
      465,  465,  465,  465,  466,  466,  466,  466,  467,  467,
      467,  467,  468,  468,  468,  468,  469,  469,  469,  469,
      470,  470,  470,  470,  471,  471,  471,  471,  472,  472,
      472,  472,  473,  473,  473,  473,  474,  474,  474,  474,
      475,  475,  475,  475,  304,  298,  295,  291,  289,  287,
      276,  268,  265,  263,  257,  248,  234,  232,  180,  118,

      116,   75,   52,   38,   31,   24,   20,    6,    5,    4,
        3,  404,  404,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  404,  404,  404
    } ;

#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yyg->yy_full_match; /* restore poss. backed-over text */ \
yyg->yy_lp = yyg->yy_full_lp; /* restore orig. accepting pos. */ \
yyg->yy_state_ptr = yyg->yy_full_state; /* restore orig. state */ \
yy_current_state = *yyg->yy_state_ptr; /* restore curr. state */ \
++yyg->yy_lp; \
goto find_rule; \
}

#define yymore() (yyg->yy_more_flag = 1)
#define YY_MORE_ADJ yyg->yy_more_len
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "libxlu_disk_l.l"
/* -*- fundamental -*- */
/*
 * libxlu_disk_l.l - parser for disk specification strings
 *
 * Copyright (C) 2011      Citrix Ltd.
 * Author Ian Jackson <ian.jackson@eu.citrix.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; version 2.1 only. with the special
 * exception on linking described in file LICENSE.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 */
/*
 * Parsing the old xm/xend/xl-4.1 disk specs is a tricky problem,
 * because the target string might in theory contain "," which is the
 * delimiter we use for stripping off things on the RHS, and ":",
 * which is the delimiter we use for stripping off things on the LHS.
 *
 * In this parser we do not support such target strings in the old
 * syntax; if the target string has to contain "," or ":" the new
 * syntax's "target=" should be used.
 */

#line 35 "libxlu_disk_l.l"
#include "libxlu_disk_i.h"

#define YY_NO_INPUT

/* The code generated by flex is missing braces in single line expressions and
 * is not properly indented, which triggers the clang misleading-indentation
 * check that has been made part of -Wall since clang 10. In order to safely
 * disable it on clang versions that don't have the diagnostic implemented
 * also disable the unknown option and pragma warning. */
#ifdef __clang__
# pragma clang diagnostic ignored "-Wunknown-pragmas"
# pragma clang diagnostic ignored "-Wunknown-warning-option"
# pragma clang diagnostic ignored "-Wmisleading-indentation"
#endif

/* Some versions of flex have a bug (Fedora bugzilla 612465) which causes
 * it to fail to declare these functions, which it defines.  So declare
 * them ourselves.  Hopefully we won't have to simultaneously support
 * a flex version which declares these differently somehow. */
int xlu__disk_yyget_column(yyscan_t yyscanner);
void xlu__disk_yyset_column(int  column_no, yyscan_t yyscanner);


/*----- useful macros and functions used in actions -----
 * we use macros in the actual rules to keep the actions short
 * and particularly to avoid repeating boilerplate values such as
 * DPC->disk, yytext, etc. */

/* Sets an enum, checking it hasn't already been set to a different value  */
#define DSET(dpc,member,enumname,str,valname) do{			\
	if (dpc->disk->member != LIBXL_DISK_##enumname##_UNKNOWN &&	\
	    dpc->disk->member != LIBXL_DISK_##enumname##_##valname) {	\
	    xlu__disk_err(dpc, str, STR(member) " respecified");	\
	} else {							\
	    dpc->disk->member = LIBXL_DISK_##enumname##_##valname;	\
	}								\
    }while(0)

/* For actions whose patterns contain '=', finds the start of the value */
#define FROMEQUALS (strchr(yytext,'=')+1)

/* Chops the delimiter off, modifying yytext and yyleng. */
#define STRIP(delim) do{                                                \
	if (yyleng>0 && yytext[yyleng-1]==(delim))                      \
	    yytext[--yyleng] = 0;                                       \
    }while(0)

/* Sets a string value, checking it hasn't been set already. */
#define SAVESTRING(what,loc,val) do{					\
	savestring(DPC, what " respecified", &DPC->disk->loc, (val));	\
    }while(0)
static void savestring(DiskParseContext *dpc, const char *what_respecified,
		       char **update, const char *value) {
    if (*update) {
        if (**update) { xlu__disk_err(dpc,value,what_respecified); return; }
        free(*update); /* do not complain about overwriting empty strings */
    }
    *update = strdup(value);
}

#define DPC dpc /* our convention in lexer helper functions */

/* Sets ->readwrite from the string.  This ought to be an enum, perhaps. */
static void setaccess(DiskParseContext *dpc, const char *str) {
    if (!strcmp(str, "r") || !strcmp(str, "ro")) {
        dpc->disk->readwrite = 0;
    } else if (!strcmp(str, "rw") || !strcmp(str, "w") || !strcmp(str,"")) {
	dpc->disk->readwrite = 1;
    } else {
	xlu__disk_err(dpc,str,"unknown value for access");
    }
}

/* Sets ->format from the string.  IDL should provide something for this. */
static void setformat(DiskParseContext *dpc, const char *str) {
    if      (!strcmp(str,""))       DSET(dpc,format,FORMAT,str,RAW);
    else if (!strcmp(str,"raw"))    DSET(dpc,format,FORMAT,str,RAW);
    else if (!strcmp(str,"qcow"))   DSET(dpc,format,FORMAT,str,QCOW);
    else if (!strcmp(str,"qcow2"))  DSET(dpc,format,FORMAT,str,QCOW2);
    else if (!strcmp(str,"vhd"))    DSET(dpc,format,FORMAT,str,VHD);
    else if (!strcmp(str,"empty"))  DSET(dpc,format,FORMAT,str,EMPTY);
    else if (!strcmp(str,"qed"))    DSET(dpc,format,FORMAT,str,QED);
    else xlu__disk_err(dpc,str,"unknown value for format");
}

/* Sets ->backend from the string.  IDL should provide something for this. */
static void setbackendtype(DiskParseContext *dpc, const char *str) {
    if (     !strcmp(str,"phy"))   DSET(dpc,backend,BACKEND,str,PHY);
    else if (!strcmp(str,"tap"))   DSET(dpc,backend,BACKEND,str,TAP);
    else if (!strcmp(str,"qdisk")) DSET(dpc,backend,BACKEND,str,QDISK);
    else if (!strcmp(str,"standalone")) DSET(dpc,backend,BACKEND,str,STANDALONE);
    else xlu__disk_err(dpc,str,"unknown value for backendtype");
}

/* Sets ->specification from the string.  IDL should provide something for this. */
static void setspecification(DiskParseContext *dpc, const char *str) {
    if      (!strcmp(str,"xen"))    DSET(dpc,specification,SPECIFICATION,str,XEN);
    else if (!strcmp(str,"virtio")) DSET(dpc,specification,SPECIFICATION,str,VIRTIO);
    else xlu__disk_err(dpc,str,"unknown value for specification");
}

/* Sets ->colo-port from the string.  COLO need this. */
static void setcoloport(DiskParseContext *dpc, const char *str) {
    int port = atoi(str);
    if (port) {
       dpc->disk->colo_port = port;
    } else {
	xlu__disk_err(dpc,str,"unknown value for colo_port");
    }
}

#define DEPRECATE(usewhatinstead) /* not currently reported */

/* Handles a vdev positional parameter which includes a devtype. */
static int vdev_and_devtype(DiskParseContext *dpc, char *str) {
    /* returns 1 if it was <vdev>:<devtype>, 0 (doing nothing) otherwise */
    char *colon = strrchr(str, ':');
    if (!colon)
        return 0;

    DEPRECATE("use `devtype=...'");
    *colon++ = 0;
    SAVESTRING("vdev", vdev, str);

    if (!strcmp(colon,"cdrom")) {
        DPC->disk->is_cdrom = 1;
    } else if (!strcmp(colon,"disk")) {
        DPC->disk->is_cdrom = 0;
    } else {
        xlu__disk_err(DPC,colon,"unknown deprecated type");
    }
    return 1;
}

#undef DPC /* needs to be defined differently the actual lexer */
#define DPC ((DiskParseContext*)yyextra)

#line 1260 "libxlu_disk_l.c"

#line 1262 "libxlu_disk_l.c"

#define INITIAL 0
#define LEXERR 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    yy_state_type *yy_state_buf;
    yy_state_type *yy_state_ptr;
    char *yy_full_match;
    int yy_lp;

    /* These are only needed for trailing context rules,
     * but there's no conditional variable for that yet. */
    int yy_looking_for_trail_begin;
    int yy_full_lp;
    int *yy_full_state;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! yyg->yy_state_buf )
            yyg->yy_state_buf = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  , yyscanner);
            if ( ! yyg->yy_state_buf )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 185 "libxlu_disk_l.l"


#line 188 "libxlu_disk_l.l"
 /*----- the scanner rules which do the parsing -----*/

#line 1544 "libxlu_disk_l.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yyg->yy_more_len = 0;
		if ( yyg->yy_more_flag )
			{
			yyg->yy_more_len = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			yyg->yy_more_flag = 0;
			}
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;

		yyg->yy_state_ptr = yyg->yy_state_buf;
		*yyg->yy_state_ptr++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 405 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*yyg->yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_current_state != 404 );

yy_find_action:
		yy_current_state = *--yyg->yy_state_ptr;
		yyg->yy_lp = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yyg->yy_lp && yyg->yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yyg->yy_lp];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     yyg->yy_looking_for_trail_begin )
					{
					if ( yy_act == yyg->yy_looking_for_trail_begin )
						{
						yyg->yy_looking_for_trail_begin = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					yyg->yy_looking_for_trail_begin = yy_act & ~YY_TRAILING_MASK;
					yyg->yy_looking_for_trail_begin |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					break;
					}
				++yyg->yy_lp;
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--yyg->yy_state_ptr;
			yyg->yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 190 "libxlu_disk_l.l"
{ /* ignore whitespace before parameters */ }
	YY_BREAK
/* ordinary parameters setting enums or strings */
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 194 "libxlu_disk_l.l"
{ STRIP(','); setformat(DPC, FROMEQUALS); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 196 "libxlu_disk_l.l"
{ DPC->disk->is_cdrom = 1; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 197 "libxlu_disk_l.l"
{ DPC->disk->is_cdrom = 1; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 198 "libxlu_disk_l.l"
{ DPC->disk->is_cdrom = 0; }
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 199 "libxlu_disk_l.l"
{ xlu__disk_err(DPC,yytext,"unknown value for type"); }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 201 "libxlu_disk_l.l"
{ STRIP(','); setaccess(DPC, FROMEQUALS); }
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 202 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("backend", backend_domname, FROMEQUALS); }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 203 "libxlu_disk_l.l"
{ STRIP(','); setbackendtype(DPC,FROMEQUALS); }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 204 "libxlu_disk_l.l"
{ STRIP(','); setspecification(DPC,FROMEQUALS); }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 206 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("vdev", vdev, FROMEQUALS); }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 207 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("script", script, FROMEQUALS); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 208 "libxlu_disk_l.l"
{ DPC->disk->direct_io_safe = 1; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 209 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->discard_enable, true); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 210 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->discard_enable, false); }
	YY_BREAK
/* Note that the COLO configuration settings should be considered unstable.
  * They may change incompatibly in future versions of Xen. */
case 16:
YY_RULE_SETUP
#line 213 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->colo_enable, true); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 214 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->colo_enable, false); }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 215 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("colo-host", colo_host, FROMEQUALS); }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 216 "libxlu_disk_l.l"
{ STRIP(','); setcoloport(DPC, FROMEQUALS); }
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 217 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("colo-export", colo_export, FROMEQUALS); }
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 218 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("active-disk", active_disk, FROMEQUALS); }
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 219 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("hidden-disk", hidden_disk, FROMEQUALS); }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 221 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->trusted, true); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 222 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->trusted, false); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 224 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->grant_usage, true); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 225 "libxlu_disk_l.l"
{ libxl_defbool_set(&DPC->disk->grant_usage, false); }
	YY_BREAK
/* the target magic parameter, eats the rest of the string */
case 27:
YY_RULE_SETUP
#line 229 "libxlu_disk_l.l"
{ STRIP(','); SAVESTRING("target", pdev_path, FROMEQUALS); }
	YY_BREAK
/* unknown parameters */
case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
#line 233 "libxlu_disk_l.l"
{ xlu__disk_err(DPC,yytext,"unknown parameter"); }
	YY_BREAK
/* deprecated prefixes */
/* the "/.*" in these patterns ensures that they count as if they
   * matched the whole string, so these patterns take precedence */
case 29:
YY_RULE_SETUP
#line 240 "libxlu_disk_l.l"
{
                    STRIP(':');
                    DPC->had_depr_prefix=1; DEPRECATE("use `[format=]...,'");
                    setformat(DPC, yytext);
                 }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 246 "libxlu_disk_l.l"
{
                    char *newscript;
                    STRIP(':');
                    DPC->had_depr_prefix=1; DEPRECATE("use `script=...'");
                    if (asprintf(&newscript, "block-%s", yytext) < 0) {
                            xlu__disk_err(DPC,yytext,"unable to format script");
                            return 0;
                    }
                    savestring(DPC, "script respecified",
                               &DPC->disk->script, newscript);
                    free(newscript);
                }
	YY_BREAK
case 31:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 8;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 259 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 260 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 33:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 261 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 34:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 262 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 35:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 263 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 36:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 264 "libxlu_disk_l.l"
{ DPC->had_depr_prefix=1; DEPRECATE(0); }
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
#line 266 "libxlu_disk_l.l"
{
		  xlu__disk_err(DPC,yytext,"unknown deprecated disk prefix");
		  return 0;
		}
	YY_BREAK
/* positional parameters */
case 38:
/* rule 38 can match eol */
YY_RULE_SETUP
#line 273 "libxlu_disk_l.l"
{
    STRIP(',');

    if (DPC->err) {
        /* previous errors may just lead to subsequent ones */
    } else if (!DPC->disk->pdev_path) {
        SAVESTRING("target", pdev_path, yytext);
    } else if (!DPC->had_depr_prefix &&
               DPC->disk->format == LIBXL_DISK_FORMAT_UNKNOWN) {
        if (!*DPC->disk->pdev_path && vdev_and_devtype(DPC,yytext)) {
            DPC->disk->format = LIBXL_DISK_FORMAT_EMPTY;
        } else {
            setformat(DPC,yytext);
        }
    } else if (!DPC->disk->vdev) {
        if (!vdev_and_devtype(DPC,yytext))
            SAVESTRING("vdev", vdev, yytext);
    } else if (!DPC->access_set) {
        DPC->access_set = 1;
        setaccess(DPC,yytext);
    } else {
        xlu__disk_err(DPC,yytext,"too many positional parameters");
        return 0; /* don't print any more errors */
    }
}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 299 "libxlu_disk_l.l"
{
    BEGIN(LEXERR);
    yymore();
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 303 "libxlu_disk_l.l"
{
    xlu__disk_err(DPC,yytext,"bad disk syntax"); return 0;
}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 306 "libxlu_disk_l.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1923 "libxlu_disk_l.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(LEXERR):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	yyg->yy_state_ptr = yyg->yy_state_buf;
	*yyg->yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 405 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*yyg->yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 405 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 404);
	if ( ! yy_is_jam )
		*yyg->yy_state_ptr++ = yy_current_state;

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

    yyg->yy_state_buf = 0;
    yyg->yy_state_ptr = 0;
    yyg->yy_full_match = 0;
    yyg->yy_lp = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    yyfree ( yyg->yy_state_buf , yyscanner);
    yyg->yy_state_buf  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 306 "libxlu_disk_l.l"
